"""Default configuration for Jodit editor."""

DEFAULT_CONFIG = {
    "height": 400,
    "width": "100%",
    "toolbar": True,
    "spellcheck": True,
    "language": "auto",
    "theme": "auto",  # 'default', 'dark', or 'auto' to detect from page/admin
    "toolbarButtonSize": "middle",
    "toolbarAdaptive": True,
    "showCharsCounter": True,
    "showWordsCounter": True,
    "showXPathInStatusbar": False,
    "askBeforePasteHTML": True,
    "askBeforePasteFromWord": True,
    "buttons": [
        "source",
        "|",
        "bold",
        "italic",
        "underline",
        "strikethrough",
        "|",
        "ul",
        "ol",
        "|",
        "outdent",
        "indent",
        "|",
        "font",
        "fontsize",
        "brush",
        "paragraph",
        "|",
        "image",
        "table",
        "link",
        "|",
        "align",
        "undo",
        "redo",
        "|",
        "hr",
        "eraser",
        "copyformat",
        "|",
        "symbol",
        "fullsize",
        "print",
    ],
    "uploader": {
        "insertImageAsBase64URI": True,
    },
    "removeButtons": [],
}
